==> xcoral-2.5-1.tar.gz: xcoral-2.5/Smac/declaration.h <==
/* ########################################################################

			     declaration.h

   File: declaration.h
   Path: /home/fournigault/c/X11/xcoral-2.33/Smac/declaration.h
   Description: 
   Created: Tue Feb 21 12:52:46 MET 1995
   Author: Bruno Pages
   Modified: Tue Feb 21 12:52:47 MET 1995
   Last maintained by: Bruno Pages

   RCS $Revision$ $State$
   

   ########################################################################

   Note: 

   ########################################################################

   Copyright (c) : Bruno Pages

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   ######################################################################## */



#ifndef _declaration_h
#define _declaration_h

#include "Instruction.h"
#include "list.h"

extern FCT(Instruction *, make_declaration,(List *)		);
extern FCT(Instruction *, make_initializer_list,(List *)	);
extern FCT(Instruction *, make_function_declaration,(List *)	);
extern FCT(void, remove_varloc,(List *, int)			);

#endif

==> xcoral-3.44.tar.gz: xcoral-3.44/Smac/declaration.h <==
/* ########################################################################

			     declaration.h

   File: declaration.h
   Path: /home/fournigault/c/X11/xcoral-2.33/Smac/declaration.h
   Description: 
   Created: Tue Feb 21 12:52:46 MET 1995
   Author: Bruno Pages
   Modified: Tue Feb 21 12:52:47 MET 1995
   Last maintained by: Bruno Pages

   RCS $Revision$ $State$
   

   ########################################################################

   Note: 

   ########################################################################

   Copyright (c) : Bruno Pages

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   ######################################################################## */



#ifndef _declaration_h
#define _declaration_h

#include "Instruction.h"
#include "list.h"

extern FCT(Instruction *, make_declaration,(List *, int)		);
extern FCT(Instruction *, make_initializer_list,(List *, int)		);
extern FCT(Instruction *, make_function_declaration,(List *, int)	);
extern FCT(void, remove_varloc,(List *, int)				);

#endif
